==> akarixb-v0.5.tar.gz: akarixb-v0.5/src/stringlistwidget.h <==
/*
 *   This file is part of AkariXB
 *   Copyright 2015-2018  JanKusanagi JRR <jancoding@gmx.com>
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the
 *   Free Software Foundation, Inc.,
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .
 */

#ifndef STRINGLISTWIDGET_H
#define STRINGLISTWIDGET_H

#include <QWidget>
#include <QHBoxLayout>
#include <QVBoxLayout>
#include <QListWidget>
#include <QToolButton>
#include <QInputDialog>
#include <QTextEdit>
#include <QPushButton>

#include <QDebug>


class StringListWidget : public QWidget
{
    Q_OBJECT

public:
    explicit StringListWidget(bool keyValue, QWidget *parent = 0);
    ~StringListWidget();

    void setLowercaseItems(bool lowercase);

    void clearList();
    void addStringsToList(QStringList stringList);
    QStringList getStringsFromList();

    void addItemsToList(QVariantMap stringMap);
    QVariantMap getItemsFromList();


signals:


public slots:
    void addToList();
    void editItem();
    void removeFromList();

    void onRowChanged(int row);

    void updateItemText();


private:
    QHBoxLayout *mainLayout;
    QListWidget *listWidget;

    QVBoxLayout *buttonsLayout;
    QToolButton *addButton;
    QToolButton *editButton;
    QToolButton *removeButton;

    QTextEdit *itemTextEdit;
    QPushButton *m_updateButton;

    bool forKeyValue;
    bool lowercaseItems;
};

#endif // STRINGLISTWIDGET_H

==> akarixb-v0.6.tar.gz: akarixb-v0.6/src/stringlistwidget.h <==
/*
 *   This file is part of AkariXB
 *   Copyright 2015-2018  JanKusanagi JRR <jancoding@gmx.com>
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the
 *   Free Software Foundation, Inc.,
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .
 */

#ifndef STRINGLISTWIDGET_H
#define STRINGLISTWIDGET_H

#include <QWidget>
#include <QHBoxLayout>
#include <QVBoxLayout>
#include <QListWidget>
#include <QToolButton>
#include <QInputDialog>
#include <QTextEdit>
#include <QPushButton>

#include <QDebug>


class StringListWidget : public QWidget
{
    Q_OBJECT

public:
    explicit StringListWidget(bool forKeyValues, QWidget *parent = nullptr);
    ~StringListWidget();

    void setLowercaseItems(bool lowercase);

    void clearList();
    void addStringsToList(QStringList stringList);
    QStringList getStringsFromList();

    void addItemsToList(QVariantMap stringMap);
    QVariantMap getItemsFromList();

    void enableRelevantButtons();

signals:


public slots:
    void addToList();
    void editItem();
    void removeFromList();

    void onRowChanged(int row);

    void updateItemText();


private:
    QHBoxLayout *m_mainLayout;
    QListWidget *m_listWidget;

    QVBoxLayout *m_buttonsLayout;
    QToolButton *m_addButton;
    QToolButton *m_editButton;
    QToolButton *m_removeButton;

    QTextEdit *m_itemTextEdit;
    QPushButton *m_updateButton;

    bool m_forKeyValues;
    bool m_lowercaseItems;
};

#endif // STRINGLISTWIDGET_H
